# Tikes

This python package is designed to distribute a few simple, low stimulation games for kids.

The intent is to introduce kids to games and interactive media in a safe, controllable
environment.

I love you, son.

